@@ -51,7 +51,10 @@ class Serialization(SerializationInterface):
         Take the tiddlers from the given bag and inject
         them into a TiddlyWiki.
         """
-        return self._put_tiddlers_in_tiddlywiki(bag.list_tiddlers())
+        try:
+            return self._put_tiddlers_in_tiddlywiki(bag.list_tiddlers())
+        except AttributeError:
+            return self._put_tiddlers_in_tiddlywiki(bag)
 
     def tiddler_as(self, tiddler):
         """
@@ -85,21 +88,8 @@ the content of this wiki</a>.
         head sections of the file.
         """
 
-        browsable_url = None
-        if tiddlers:
-            if tiddlers[0].recipe:
-                workspace = '/recipes/%s/tiddlers' % encode_name(
-                        tiddlers[0].recipe)
-            else:
-                workspace = '/bags/%s/tiddlers' % encode_name(tiddlers[0].bag)
-            browsable_url = server_base_url(self.environ) + workspace
-
-        if len(tiddlers) == 1:
-            default_tiddler = Tiddler('DefaultTiddlers')
-            default_tiddler.text = '[[' + tiddlers[0].title + ']]'
-            tiddlers = [tiddlers[0], default_tiddler]
-
-        lines, title, found_markup_tiddlers = self._create_tiddlers(title, tiddlers)
+        (browsable_url, lines, title,
+                found_markup_tiddlers) = self._create_tiddlers(title, tiddlers)
 
         # load the wiki
         wiki = self._get_wiki()
@@ -128,27 +118,44 @@ the content of this wiki</a>.
         wiki and calculate the title.
         """
         lines = ''
+        window_title = None
         candidate_title = None
         candidate_subtitle = None
         markup_tiddlers = MARKUPS.keys()
         found_markup_tiddlers = {}
+        tiddler_count = 0
         for tiddler in tiddlers:
             lines += self._tiddler_as_div(tiddler)
             tiddler_title = tiddler.title
+            if tiddler_title == 'WindowTitle':
+                window_title = tiddler.text
             if tiddler_title == 'SiteTitle':
                 candidate_title = tiddler.text
             if tiddler_title == 'SiteSubtitle':
                 candidate_subtitle = tiddler.text
             if tiddler_title in markup_tiddlers:
                 found_markup_tiddlers[tiddler_title] = tiddler.text
+            tiddler_count += 1
+
+        if tiddler_count == 1:
+            default_tiddler = Tiddler('DefaultTiddlers')
+            default_tiddler.text = '[[' + tiddler.title + ']]'
+            lines += self._tiddler_as_div(default_tiddler)
+
+        browsable_url = None
+        if tiddler.recipe:
+            workspace = '/recipes/%s/tiddlers' % encode_name(tiddler.recipe)
+        else:
+            workspace = '/bags/%s/tiddlers' % encode_name(tiddler.bag)
+        browsable_url = server_base_url(self.environ) + workspace
 
         # Turn the title into HTML and then turn it into
         # plain text so it is of a form satisfactory to <title>
-        title = self._determine_title(title, candidate_title,
+        title = self._determine_title(title, window_title, candidate_title,
                 candidate_subtitle)
         title = self._plain_textify_string(title)
 
-        return lines, title, found_markup_tiddlers
+        return browsable_url, lines, title, found_markup_tiddlers
 
     def _plain_textify_string(self, title):
         """
@@ -172,11 +179,13 @@ the content of this wiki</a>.
         title = _get_text(dom.childNodes)
         return ''.join(title).rstrip().lstrip()
 
-    def _determine_title(self, title, candidate_title, candidate_subtitle):
+    def _determine_title(self, title, window_title, candidate_title, candidate_subtitle):
         """
         Create a title for the wiki file from various
         optional inputs.
         """
+        if window_title:
+            return window_title
         if candidate_title and candidate_subtitle:
             return '%s - %s' % (candidate_title, candidate_subtitle)
         if candidate_title:
@@ -230,13 +239,16 @@ the content of this wiki</a>.
 
         if tiddler.type and tiddler.type != 'None':
             tiddler_output = self._binary_tiddler(tiddler)
+            content_type = tiddler.type
         else:
             tiddler_output = tiddler.text
+            content_type = ''
 
         return ('<div title="%s" server.title="%s" server.page.revision="%s" '
                 'modifier="%s" creator="%s" server.workspace="bags/%s" '
                 'server.type="tiddlyweb" server.host="%s" '
                 'server.recipe="%s" server.bag="%s" server.permissions="%s" '
+                'server.content-type="%s" '
                 'modified="%s" created="%s" tags="%s" %s>\n'
                 '<pre>%s</pre>\n</div>\n' %
                     (escape_attribute_value(tiddler.title),
@@ -249,6 +261,7 @@ the content of this wiki</a>.
                         escape_attribute_value(recipe_name),
                         escape_attribute_value(tiddler.bag),
                         self._tiddler_permissions(tiddler),
+                        content_type,
                         tiddler.modified,
                         tiddler.created,
                         escape_attribute_value(self.tags_as(tiddler.tags)),
